atomate.feff.workflows.tests package — atomate 0.9.2 documentation

# atomate.feff.workflows.tests package

## Submodules

## atomate.feff.workflows.tests.test_eels_workflows module

class `atomate.feff.workflows.tests.test_eels_workflows.` `TestEELSWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_eels_wflow_abatom_by_idx`()
  `test_eels_wflow_abatom_by_symbol`()
  `test_elnes_vs_exelfs`()

## atomate.feff.workflows.tests.test_exafs_scattering_paths module

class `atomate.feff.workflows.tests.test_exafs_scattering_paths.` `TestEXAFSPaths`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_feff_input_sets`()
  `test_paths`()
  `test_wflow_composition`()

## atomate.feff.workflows.tests.test_xas_workflows module

class `atomate.feff.workflows.tests.test_xas_workflows.` `TestXASWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_xanes_vs_exafs`()
  `test_xas_wflow_abatom_by_idx`()
  `test_xas_wflow_abatom_by_symbol`()

## Module contents